@@ -3,7 +3,7 @@
   Author: Marc Mutz <mutz@kde.org>
   based upon work by Stefan Taferner <taferner@kde.org>
 
-  Copyright (c) 2011-2018 Laurent Montel <montel@kde.org>
+  Copyright (c) 2011-2019 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -170,10 +170,10 @@ KMFilterDialog::KMFilterDialog(const QList<KActionCollection *> &actionCollectio
     mainLayout->addWidget(w);
     mainLayout->addWidget(buttonBox);
     QVBoxLayout *topVLayout = new QVBoxLayout(w);
-    topVLayout->setMargin(0);
+    topVLayout->setContentsMargins(0, 0, 0, 0);
     QHBoxLayout *topLayout = new QHBoxLayout;
     topVLayout->addLayout(topLayout);
-    topLayout->setMargin(0);
+    topLayout->setContentsMargins(0, 0, 0, 0);
 
     QSplitter *splitter = new QSplitter;
     splitter->setChildrenCollapsible(false);
@@ -296,7 +296,7 @@ KMFilterDialog::KMFilterDialog(const QList<KActionCollection *> &actionCollectio
 
         QWidget *hbox = new QWidget(mAdvOptsGroup);
         QHBoxLayout *hboxHBoxLayout = new QHBoxLayout(hbox);
-        hboxHBoxLayout->setMargin(0);
+        hboxHBoxLayout->setContentsMargins(0, 0, 0, 0);
         mFilterActionLabel = new QLabel(i18n("Icon for this filter:"), hbox);
         hboxHBoxLayout->addWidget(mFilterActionLabel);
         mFilterActionLabel->setEnabled(false);
